==> Paws-0.38.tar.gz: Paws-0.38/lib/Paws/ES/DescribeReservedElasticsearchInstances.pm <==

package Paws::ES::DescribeReservedElasticsearchInstances;
  use Moose;
  has MaxResults => (is => 'ro', isa => 'Int', traits => ['ParamInQuery'], query_name => 'maxResults');
  has NextToken => (is => 'ro', isa => 'Str', traits => ['ParamInQuery'], query_name => 'nextToken');
  has ReservedElasticsearchInstanceId => (is => 'ro', isa => 'Str', traits => ['ParamInQuery'], query_name => 'reservationId');

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DescribeReservedElasticsearchInstances');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/2015-01-01/es/reservedInstances');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'GET');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::ES::DescribeReservedElasticsearchInstancesResponse');
1;

### main pod documentation begin ###

=head1 NAME

Paws::ES::DescribeReservedElasticsearchInstances - Arguments for method DescribeReservedElasticsearchInstances on L<Paws::ES>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DescribeReservedElasticsearchInstances on the
L<Amazon Elasticsearch Service|Paws::ES> service. Use the attributes of this class
as arguments to method DescribeReservedElasticsearchInstances.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DescribeReservedElasticsearchInstances.

=head1 SYNOPSIS

    my $es = Paws->service('ES');
    my $DescribeReservedElasticsearchInstancesResponse =
      $es->DescribeReservedElasticsearchInstances(
      MaxResults                      => 1,                # OPTIONAL
      NextToken                       => 'MyNextToken',    # OPTIONAL
      ReservedElasticsearchInstanceId => 'MyGUID',         # OPTIONAL
      );

    # Results:
    my $NextToken = $DescribeReservedElasticsearchInstancesResponse->NextToken;
    my $ReservedElasticsearchInstances =
      $DescribeReservedElasticsearchInstancesResponse
      ->ReservedElasticsearchInstances;

 # Returns a L<Paws::ES::DescribeReservedElasticsearchInstancesResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://aws.amazon.com/documentation/elasticsearch-service/>

=head1 ATTRIBUTES


=head2 MaxResults => Int

Set this value to limit the number of results returned. If not
specified, defaults to 100.



=head2 NextToken => Str

NextToken should be sent in case if earlier API call produced result
containing NextToken. It is used for pagination.



=head2 ReservedElasticsearchInstanceId => Str

The reserved instance identifier filter value. Use this parameter to
show only the reservation that matches the specified reserved
Elasticsearch instance ID.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DescribeReservedElasticsearchInstances in L<Paws::ES>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

==> Paws-0.46.tar.gz: Paws-0.46/lib/Paws/ES/DescribeReservedElasticsearchInstances.pm <==

package Paws::ES::DescribeReservedElasticsearchInstances;
  use Moose;
  has MaxResults => (is => 'ro', isa => 'Int', traits => ['ParamInQuery'], query_name => 'maxResults');
  has NextToken => (is => 'ro', isa => 'Str', traits => ['ParamInQuery'], query_name => 'nextToken');
  has ReservedElasticsearchInstanceId => (is => 'ro', isa => 'Str', traits => ['ParamInQuery'], query_name => 'reservationId');

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DescribeReservedElasticsearchInstances');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/2015-01-01/es/reservedInstances');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'GET');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::ES::DescribeReservedElasticsearchInstancesResponse');
1;

### main pod documentation begin ###

=head1 NAME

Paws::ES::DescribeReservedElasticsearchInstances - Arguments for method DescribeReservedElasticsearchInstances on L<Paws::ES>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DescribeReservedElasticsearchInstances on the
L<Amazon Elasticsearch Service|Paws::ES> service. Use the attributes of this class
as arguments to method DescribeReservedElasticsearchInstances.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DescribeReservedElasticsearchInstances.

=head1 SYNOPSIS

    my $es = Paws->service('ES');
    my $DescribeReservedElasticsearchInstancesResponse =
      $es->DescribeReservedElasticsearchInstances(
      MaxResults                      => 1,                # OPTIONAL
      NextToken                       => 'MyNextToken',    # OPTIONAL
      ReservedElasticsearchInstanceId => 'MyGUID',         # OPTIONAL
      );

    # Results:
    my $NextToken = $DescribeReservedElasticsearchInstancesResponse->NextToken;
    my $ReservedElasticsearchInstances =
      $DescribeReservedElasticsearchInstancesResponse
      ->ReservedElasticsearchInstances;

 # Returns a L<Paws::ES::DescribeReservedElasticsearchInstancesResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/es/DescribeReservedElasticsearchInstances>

=head1 ATTRIBUTES


=head2 MaxResults => Int

Set this value to limit the number of results returned. If not
specified, defaults to 100.



=head2 NextToken => Str

NextToken should be sent in case if earlier API call produced result
containing NextToken. It is used for pagination.



=head2 ReservedElasticsearchInstanceId => Str

The reserved instance identifier filter value. Use this parameter to
show only the reservation that matches the specified reserved
Elasticsearch instance ID.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DescribeReservedElasticsearchInstances in L<Paws::ES>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
